==> duiba-galaxy-sdk-0.0.1-20221209.065512-70-sources.jar: cn/com/duiba/galaxy/sdk/ProjectApi.java <==
package cn.com.duiba.galaxy.sdk;

import cn.com.duiba.galaxy.sdk.base.StrategyResult;
import cn.com.duiba.galaxy.sdk.base.UserData;
import cn.com.duiba.galaxy.sdk.datas.Option;
import cn.com.duiba.galaxy.sdk.datas.Option4Inner;
import cn.com.duiba.galaxy.sdk.datas.UserSpRecordNew;
import cn.com.duiba.galaxy.sdk.emums.StrategyTypeEnum;
import cn.com.duiba.galaxy.sdk.utils.PageList;
import cn.com.duiba.wolf.entity.Pair;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;
import java.util.Map;

public interface ProjectApi extends Api {

    /**
     * 获取项目开始时间、结束时间
     */
    Pair<Date, Date> getProjectTime();


//
//    PrizeStock getPrizeStock(String prizeId);
//
//    /**
//     * 批量获取奖品库存信息
//     * @param ids prize ids
//     * @return prize stock list
//     */
//    List<PrizeStock> listPrizeStock(List<String> ids);
//
//    Prize getPrize(String prizeId);
//
//    List<Prize> getPrizeList(List<String> prizeIds);

    /**
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(Long userId, String spId, int quantity);

    /**
     * 注意：慎用，quantity传long,避免sp_record sum报错
     * <p>
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(Long userId, String spId, long quantity);


//    /**
//     * 获取一个http请求实例,不同project之间相互隔离
//     *
//     * @return
//     */
//    HttpHelper getHttpHelper();
//
//
//    /**
//     * 获取RestTemplate
//     *
//     * 内网服务调用，域名直接用服务名，有默认负载均衡
//     * @return
//     */
//    RestTemplate getRestTemplate();
//
//    /**
//     * 获取异步http请求实例
//     * @return
//     */
//    HttpAsyncClient getHttpAsyncClient();
//
//    /**
//     * 获取一个https请求实例
//     *
//     * @param name     实例的名称，不同实例间隔离
//     * @param keyStore 证书
//     * @return
//     */
//    HttpHelper getHttpHelper(String name, KeyStore keyStore);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(Long userId, String spId, int quantity);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(Long userId, String spId, long quantity);

    /**
     * 查询某人所有的道具的数量信息
     *
     * @param userId 需要查询的用户
     * @return key:道具id，value:拥有的道具数
     */
    Map<String, Long> getSomebodyAllStageProperty(Long userId);

    /**
     * 查询某些用户的某个道具数
     *
     * @param userIds 用户id最多支持1000人，超过抛异常
     * @param spId    sp id
     * @return map user id -> sp count
     */
    Map<Long, Long> getSpByUserIds(List<String> userIds, String spId);

    /**
     * 查询某人的某个道具的数量
     *
     * @param userId 需要查询的用户
     * @param spId   道具id
     * @return
     */
    Long getSomebodyStageProperty(Long userId, String spId);

    /**
     * 获取某个发奖策略下面的奖项列表
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option> queryOptions(String strategyId);


    /**
     * 获取某个发奖策略下面的奖项列表(内部使用，会暴露中奖概率)
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option4Inner> queryOptions4Inner(String strategyId);

    /**
     * list user data
     * user id 的个数不能超过500个，超过会抛异常
     *
     * @param key     key
     * @param userIds user ids
     * @return user data listk
     */
    List<UserData> batchListUserData(String key, List<String> userIds);

//    /**
//     * 判断某个用户是否是开发者白名单用户
//     *
//     * @param partnerUserId
//     * @param projectId
//     * @return user data list
//     */
//    Boolean isWhiteListUser(Long projectId ,String partnerUserId);
//
//    /**
//     * 获取某个用户在白名单的的一行记录的多列数据
//     *
//     * @param projectId 项目ID
//     * @param partnerUserId 用户标识
//     * @param groupId 分组ID   注：不传默认为：0
//     * @return
//     */
//    String[] getWhiteListByUserId(Long projectId ,String partnerUserId, String groupId);
//
//    /**
//     * 查询用户命中的白名单列表
//     * @param partnerUserId 用户标识
//     * @param groupIds 白名单group范围，可不填
//     * @return 命中的白名单groupId列表(不为空，size可为0),最多获取100条
//     */
//    List<String> getWhiteListUserByPIdAndGroupIds(String partnerUserId, Collection<String> groupIds);
//
//    /**
//     * 获取开发者白名单下某个 group 的白名单集合
//     * @param groupId
//     * @return
//     */
//    List<String> getWhiteListByGroup(String groupId);

    // TODO: 2022/10/22 中奖记录
//    /**
//     * 获取当前用户中奖纪录列表
//     * 本接口只查询数据库中最近的1000条纪录，并对其中的加积分奖品进行筛选或不筛选
//     *
//     * @param ignoreAddCredits 是否忽略加积分奖品   true: 忽略  false:不忽略
//     * @return
//     */
//    List<UserPrizeRecord> listUserPrizeRecord(boolean ignoreAddCredits);
//
//    /**
//     * 获取制定用户中奖纪录列表
//     * 本接口只查询数据库中最近的1000条纪录，并对其中的加积分奖品进行筛选或不筛选
//     *
//     * @param userId           用户ID
//     * @param ignoreAddCredits 是否忽略加积分奖品   true: 忽略  false:不忽略
//     * @return
//     */
//    List<UserPrizeRecord> listSomebodyUserPrizeRecord(Long userId, boolean ignoreAddCredits);


//    /**
//     * 判断某个用户在当前项目是否是开发者白名单用户
//     * @param partnerUserId
//     * @param groupId 分组类型id （不使用传null，默认查所有组）
//     * @return
//     */
//    Boolean isWhiteListUserByPIdAndGroupId(String partnerUserId ,String groupId);
//
//    /**
//     * 根据partnerUserId，groupId删除白名单
//     * @param partnerUserIds
//     * @param groupId 分组类型id （不使用传null，默认查所有组）
//     * @return
//     */
//    int deleteByPIdAndGroupId(Long projectId,String groupId,List<String> partnerUserIds);
//
//    /**
//     * 新增白名单,主键或（projectId，groupId，partnerUserId）唯一索引冲突则更新
//     * @param partnerUserId
//     * @param partnerExtra 扩展字段
//     * @param groupId 分组类型id （不传，默认 0）
//     * @return
//     */
//    int insertOrUpdate(Long projectId,String groupId,String partnerUserId,String partnerExtra);
//
//    /**
//     * 批量新增白名单，一次最多2000条 主键或（projectId，groupId，partnerUserId）唯一索引冲突则更新
//     * @param projectWhiteListDataList 只需传partnerUserId，和partnerExtra
//     * @param groupId 分组类型id
//     * @return
//     */
//    int insertOrUpdateList(Long projectId,String groupId,List<ProjectWhiteListData> projectWhiteListDataList);
//
//
//    /**
//     * 根据pid获取白名单用户信息（根据groupId去重）
//     * @param partnerUserId
//     * @return
//     */
//    List<ProjectWhiteListData> listWhiteByPartnerUserId(String partnerUserId);
//
//
//    /**
//     * 根据groupId获取白名单用户信息
//     * @param groupId
//     * @param page
//     * @param pageSize
//     * @param startId 开始id，包括此id，可以为空
//     * @return
//     */
//    PageList<ProjectWhiteListData> listWhiteByGroupId(String groupId, int page, int pageSize,Long startId);

    /**
     * sum sp record
     * 获取扣减的或者增加的总数
     * 只能永久道具使用。
     *
     * @param userId user id
     * @param spId   sp id
     * @param type   + -
     * @return sum
     */
    Long sumSpRecord(Long userId, String spId, String type);

    /**
     * 分页页查询用户道具记录
     * ⚠️ PageSize 不能大于200
     *
     * @param userId
     * @param spId
     * @param pageNum
     * @param pageSize
     * @return
     */
    PageList<UserSpRecordNew> pageQuerySpRecord(Long userId, String spId, long pageNum, long pageSize);

    /**
     * 根据时间范围分页页查询用户道具记录
     * ⚠️ PageSize 不能大于200
     *
     * @param userId
     * @param spId
     * @param pageNum
     * @param pageSize
     * @return
     */
    PageList<UserSpRecordNew> pageQuerySpRecord(Long userId, String spId, long pageNum, long pageSize, LocalDateTime startTime, LocalDateTime endTime);


//    /**
//     * 组件API
//     *
//     * @return
//     */
//    ComponentApi getComponentApi();
//

    /**
     * 根据场景id查询对应的发奖规则
     *
     * @param sceneId
     * @return
     */
    List<String> queryRuIdsBySceneId(String sceneId);


    /**
     * 根据场景id发奖
     *
     * @param sceneId
     * @return
     */
    StrategyResult sendPrizeBySceneId(String sceneId);


    /**
     * 获取启用策略类型
     * 注意:目前只针对模板活动查询已启用的发奖规则
     *
     * @return {@link List}<{@link String}>
     */
    StrategyTypeEnum getEnableStrategyType();

}

==> duiba-galaxy-sdk-0.0.3-sources.jar: cn/com/duiba/galaxy/sdk/ProjectApi.java <==
package cn.com.duiba.galaxy.sdk;

import cn.com.duiba.galaxy.sdk.base.StrategyResult;
import cn.com.duiba.galaxy.sdk.base.UserData;
import cn.com.duiba.galaxy.sdk.datas.Option;
import cn.com.duiba.galaxy.sdk.datas.Option4Inner;
import cn.com.duiba.galaxy.sdk.datas.UserSpRecordNew;
import cn.com.duiba.galaxy.sdk.emums.StrategyTypeEnum;
import cn.com.duiba.galaxy.sdk.utils.PageList;
import cn.com.duiba.wolf.entity.Pair;
import org.springframework.web.client.RestTemplate;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;
import java.util.Map;

public interface ProjectApi extends Api {

    /**
     * 获取项目开始时间、结束时间
     */
    Pair<Date, Date> getProjectTime();


//
//    PrizeStock getPrizeStock(String prizeId);
//
//    /**
//     * 批量获取奖品库存信息
//     * @param ids prize ids
//     * @return prize stock list
//     */
//    List<PrizeStock> listPrizeStock(List<String> ids);
//
//    Prize getPrize(String prizeId);
//
//    List<Prize> getPrizeList(List<String> prizeIds);

    /**
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(Long userId, String spId, int quantity);

    /**
     * 注意：慎用，quantity传long,避免sp_record sum报错
     * <p>
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(Long userId, String spId, long quantity);


    /**
     * 获取一个http请求实例,不同project之间相互隔离
     *
     * @return
     */
    HttpHelper getHttpHelper();
//
//
    /**
     * 获取 loadBalancedRestTemplate
     *
     * 通过 @LoadBalanced 注解的 RestTemplate 的Bean，可以作为 Load Balancer Client 来使用
     * @return
     */
    RestTemplate getLoadBalancedRestTemplate();

//
    /**
     * 获取异步http请求实例
     * @return
     */
   // HttpAsyncClient getHttpAsyncClient();
//
//    /**
//     * 获取一个https请求实例
//     *
//     * @param name     实例的名称，不同实例间隔离
//     * @param keyStore 证书
//     * @return
//     */
//    HttpHelper getHttpHelper(String name, KeyStore keyStore);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(Long userId, String spId, int quantity);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(Long userId, String spId, long quantity);

    /**
     * 查询某人所有的道具的数量信息
     *
     * @param userId 需要查询的用户
     * @return key:道具id，value:拥有的道具数
     */
    Map<String, Long> getSomebodyAllStageProperty(Long userId);

    /**
     * 查询某些用户的某个道具数
     *
     * @param userIds 用户id最多支持1000人，超过抛异常
     * @param spId    sp id
     * @return map user id -> sp count
     */
    Map<Long, Long> getSpByUserIds(List<String> userIds, String spId);

    /**
     * 查询某人的某个道具的数量
     *
     * @param userId 需要查询的用户
     * @param spId   道具id
     * @return
     */
    Long getSomebodyStageProperty(Long userId, String spId);

    /**
     * 获取某个发奖策略下面的奖项列表
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option> queryOptions(String strategyId);


    /**
     * 获取某个发奖策略下面的奖项列表(内部使用，会暴露中奖概率)
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option4Inner> queryOptions4Inner(String strategyId);

    /**
     * list user data
     * user id 的个数不能超过500个，超过会抛异常
     *
     * @param key     key
     * @param userIds user ids
     * @return user data listk
     */
    List<UserData> batchListUserData(String key, List<String> userIds);

//    /**
//     * 判断某个用户是否是开发者白名单用户
//     *
//     * @param partnerUserId
//     * @param projectId
//     * @return user data list
//     */
//    Boolean isWhiteListUser(Long projectId ,String partnerUserId);
//
//    /**
//     * 获取某个用户在白名单的的一行记录的多列数据
//     *
//     * @param projectId 项目ID
//     * @param partnerUserId 用户标识
//     * @param groupId 分组ID   注：不传默认为：0
//     * @return
//     */
//    String[] getWhiteListByUserId(Long projectId ,String partnerUserId, String groupId);
//
//    /**
//     * 查询用户命中的白名单列表
//     * @param partnerUserId 用户标识
//     * @param groupIds 白名单group范围，可不填
//     * @return 命中的白名单groupId列表(不为空，size可为0),最多获取100条
//     */
//    List<String> getWhiteListUserByPIdAndGroupIds(String partnerUserId, Collection<String> groupIds);
//
//    /**
//     * 获取开发者白名单下某个 group 的白名单集合
//     * @param groupId
//     * @return
//     */
//    List<String> getWhiteListByGroup(String groupId);

    // TODO: 2022/10/22 中奖记录
//    /**
//     * 获取当前用户中奖纪录列表
//     * 本接口只查询数据库中最近的1000条纪录，并对其中的加积分奖品进行筛选或不筛选
//     *
//     * @param ignoreAddCredits 是否忽略加积分奖品   true: 忽略  false:不忽略
//     * @return
//     */
//    List<UserPrizeRecord> listUserPrizeRecord(boolean ignoreAddCredits);
//
//    /**
//     * 获取制定用户中奖纪录列表
//     * 本接口只查询数据库中最近的1000条纪录，并对其中的加积分奖品进行筛选或不筛选
//     *
//     * @param userId           用户ID
//     * @param ignoreAddCredits 是否忽略加积分奖品   true: 忽略  false:不忽略
//     * @return
//     */
//    List<UserPrizeRecord> listSomebodyUserPrizeRecord(Long userId, boolean ignoreAddCredits);


//    /**
//     * 判断某个用户在当前项目是否是开发者白名单用户
//     * @param partnerUserId
//     * @param groupId 分组类型id （不使用传null，默认查所有组）
//     * @return
//     */
//    Boolean isWhiteListUserByPIdAndGroupId(String partnerUserId ,String groupId);
//
//    /**
//     * 根据partnerUserId，groupId删除白名单
//     * @param partnerUserIds
//     * @param groupId 分组类型id （不使用传null，默认查所有组）
//     * @return
//     */
//    int deleteByPIdAndGroupId(Long projectId,String groupId,List<String> partnerUserIds);
//
//    /**
//     * 新增白名单,主键或（projectId，groupId，partnerUserId）唯一索引冲突则更新
//     * @param partnerUserId
//     * @param partnerExtra 扩展字段
//     * @param groupId 分组类型id （不传，默认 0）
//     * @return
//     */
//    int insertOrUpdate(Long projectId,String groupId,String partnerUserId,String partnerExtra);
//
//    /**
//     * 批量新增白名单，一次最多2000条 主键或（projectId，groupId，partnerUserId）唯一索引冲突则更新
//     * @param projectWhiteListDataList 只需传partnerUserId，和partnerExtra
//     * @param groupId 分组类型id
//     * @return
//     */
//    int insertOrUpdateList(Long projectId,String groupId,List<ProjectWhiteListData> projectWhiteListDataList);
//
//
//    /**
//     * 根据pid获取白名单用户信息（根据groupId去重）
//     * @param partnerUserId
//     * @return
//     */
//    List<ProjectWhiteListData> listWhiteByPartnerUserId(String partnerUserId);
//
//
//    /**
//     * 根据groupId获取白名单用户信息
//     * @param groupId
//     * @param page
//     * @param pageSize
//     * @param startId 开始id，包括此id，可以为空
//     * @return
//     */
//    PageList<ProjectWhiteListData> listWhiteByGroupId(String groupId, int page, int pageSize,Long startId);

    /**
     * sum sp record
     * 获取扣减的或者增加的总数
     * 只能永久道具使用。
     *
     * @param userId user id
     * @param spId   sp id
     * @param type   + -
     * @return sum
     */
    Long sumSpRecord(Long userId, String spId, String type);

    /**
     * 分页页查询用户道具记录
     * ⚠️ PageSize 不能大于200
     *
     * @param userId
     * @param spId
     * @param pageNum
     * @param pageSize
     * @return
     */
    PageList<UserSpRecordNew> pageQuerySpRecord(Long userId, String spId, long pageNum, long pageSize);

    /**
     * 根据时间范围分页页查询用户道具记录
     * ⚠️ PageSize 不能大于200
     *
     * @param userId
     * @param spId
     * @param pageNum
     * @param pageSize
     * @return
     */
    PageList<UserSpRecordNew> pageQuerySpRecord(Long userId, String spId, long pageNum, long pageSize, LocalDateTime startTime, LocalDateTime endTime);


//    /**
//     * 组件API
//     *
//     * @return
//     */
//    ComponentApi getComponentApi();
//

    /**
     * 根据场景id查询对应的发奖规则
     *
     * @param sceneId
     * @return
     */
    List<String> queryRuIdsBySceneId(String sceneId);


    /**
     * 根据场景id发奖
     *
     * @param sceneId
     * @return
     */
    StrategyResult sendPrizeBySceneId(String sceneId);


    /**
     * 获取启用策略类型
     * 注意:目前只针对模板活动查询已启用的发奖规则
     *
     * @return {@link List}<{@link String}>
     */
    StrategyTypeEnum getEnableStrategyType();

}
